==> xdg-desktop-portal-kde-6.5.5-1.gpkg.tar: image/usr/src/debug/kde-plasma/xdg-desktop-portal-kde-6.5.5/xdg-desktop-portal-kde-6.5.5_build/src/.qt/rcc/qrc_qmake_org_kde_xdgdesktopportal.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xde,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x6b,0x64,0x65,0x2e,0x78,0x64,
  0x67,0x64,0x65,0x73,0x6b,0x74,0x6f,0x70,0x70,0x6f,0x72,0x74,0x61,0x6c,0xa,0x74,
  0x79,0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,0x78,0x64,0x67,0x2d,0x64,0x65,0x73,0x6b,
  0x74,0x6f,0x70,0x2d,0x70,0x6f,0x72,0x74,0x61,0x6c,0x2d,0x6b,0x64,0x65,0x2e,0x71,
  0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,
  0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x6f,0x72,0x67,0x2f,0x6b,0x64,0x65,0x2f,
  0x78,0x64,0x67,0x64,0x65,0x73,0x6b,0x74,0x6f,0x70,0x70,0x6f,0x72,0x74,0x61,0x6c,
  0x2f,0xa,0x53,0x63,0x72,0x65,0x65,0x6e,0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,0x63,0x72,0x65,0x65,0x6e,
  0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x55,0x73,0x65,0x72,0x49,0x6e,0x66,0x6f,0x44,0x69,0x61,0x6c,0x6f,0x67,
  0x20,0x31,0x2e,0x30,0x20,0x55,0x73,0x65,0x72,0x49,0x6e,0x66,0x6f,0x44,0x69,0x61,
  0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x63,0x63,0x65,0x73,0x73,0x44,0x69,
  0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x41,0x63,0x63,0x65,0x73,0x73,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x43,0x68,0x6f,
  0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x41,
  0x70,0x70,0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,
  0x71,0x6d,0x6c,0xa,0x52,0x65,0x6d,0x6f,0x74,0x65,0x44,0x65,0x73,0x6b,0x74,0x6f,
  0x70,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x52,0x65,0x6d,0x6f,
  0x74,0x65,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,
  0x71,0x6d,0x6c,0xa,0x53,0x63,0x72,0x65,0x65,0x6e,0x73,0x68,0x6f,0x74,0x44,0x69,
  0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,0x63,0x72,0x65,0x65,0x6e,0x73,
  0x68,0x6f,0x74,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x44,0x79,
  0x6e,0x61,0x6d,0x69,0x63,0x4c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x44,0x69,0x61,
  0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x44,0x79,0x6e,0x61,0x6d,0x69,0x63,0x4c,
  0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x50,0x69,0x70,0x65,0x57,0x69,0x72,0x65,0x44,0x65,0x6c,0x65,0x67,0x61,
  0x74,0x65,0x20,0x31,0x2e,0x30,0x20,0x50,0x69,0x70,0x65,0x57,0x69,0x72,0x65,0x44,
  0x65,0x6c,0x65,0x67,0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x49,0x6e,0x70,0x75,
  0x74,0x43,0x61,0x70,0x74,0x75,0x72,0x65,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,
  0x2e,0x30,0x20,0x49,0x6e,0x70,0x75,0x74,0x43,0x61,0x70,0x74,0x75,0x72,0x65,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x6c,0x6f,0x62,0x61,0x6c,
  0x53,0x68,0x6f,0x72,0x74,0x63,0x75,0x74,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,
  0x31,0x2e,0x30,0x20,0x47,0x6c,0x6f,0x62,0x61,0x6c,0x53,0x68,0x6f,0x72,0x74,0x63,
  0x75,0x74,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x57,0x61,
  0x6c,0x6c,0x70,0x61,0x70,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,
  0x30,0x20,0x57,0x61,0x6c,0x6c,0x70,0x61,0x70,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,
  0x67,0x2e,0x71,0x6d,0x6c,0xa,0x52,0x65,0x67,0x69,0x6f,0x6e,0x53,0x65,0x6c,0x65,
  0x63,0x74,0x4f,0x76,0x65,0x72,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x52,0x65,
  0x67,0x69,0x6f,0x6e,0x53,0x65,0x6c,0x65,0x63,0x74,0x4f,0x76,0x65,0x72,0x6c,0x61,
  0x79,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x6c,0x6f,0x61,0x74,0x69,0x6e,0x67,0x54,0x65,
  0x78,0x74,0x42,0x6f,0x78,0x20,0x31,0x2e,0x30,0x20,0x46,0x6c,0x6f,0x61,0x74,0x69,
  0x6e,0x67,0x54,0x65,0x78,0x74,0x42,0x6f,0x78,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x6c,
  0x6f,0x61,0x74,0x69,0x6e,0x67,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,
  0x20,0x31,0x2e,0x30,0x20,0x46,0x6c,0x6f,0x61,0x74,0x69,0x6e,0x67,0x42,0x61,0x63,
  0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // xdgdesktopportal
  0x0,0x10,
  0x2,0xe5,0x67,0xdc,
  0x0,0x78,
  0x0,0x64,0x0,0x67,0x0,0x64,0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x61,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/xdgdesktopportal
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/xdgdesktopportal/qmldir
  0x0,0x0,0x0,0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xc3,0x56,0xed,0x14,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> xdg-desktop-portal-kde-6.5.5-2.gpkg.tar: image/usr/src/debug/kde-plasma/xdg-desktop-portal-kde-6.5.5/xdg-desktop-portal-kde-6.5.5_build/src/.qt/rcc/qrc_qmake_org_kde_xdgdesktopportal.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xde,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x6b,0x64,0x65,0x2e,0x78,0x64,
  0x67,0x64,0x65,0x73,0x6b,0x74,0x6f,0x70,0x70,0x6f,0x72,0x74,0x61,0x6c,0xa,0x74,
  0x79,0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,0x78,0x64,0x67,0x2d,0x64,0x65,0x73,0x6b,
  0x74,0x6f,0x70,0x2d,0x70,0x6f,0x72,0x74,0x61,0x6c,0x2d,0x6b,0x64,0x65,0x2e,0x71,
  0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,
  0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x6f,0x72,0x67,0x2f,0x6b,0x64,0x65,0x2f,
  0x78,0x64,0x67,0x64,0x65,0x73,0x6b,0x74,0x6f,0x70,0x70,0x6f,0x72,0x74,0x61,0x6c,
  0x2f,0xa,0x53,0x63,0x72,0x65,0x65,0x6e,0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,0x63,0x72,0x65,0x65,0x6e,
  0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x55,0x73,0x65,0x72,0x49,0x6e,0x66,0x6f,0x44,0x69,0x61,0x6c,0x6f,0x67,
  0x20,0x31,0x2e,0x30,0x20,0x55,0x73,0x65,0x72,0x49,0x6e,0x66,0x6f,0x44,0x69,0x61,
  0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x63,0x63,0x65,0x73,0x73,0x44,0x69,
  0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x41,0x63,0x63,0x65,0x73,0x73,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x43,0x68,0x6f,
  0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x41,
  0x70,0x70,0x43,0x68,0x6f,0x6f,0x73,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,
  0x71,0x6d,0x6c,0xa,0x52,0x65,0x6d,0x6f,0x74,0x65,0x44,0x65,0x73,0x6b,0x74,0x6f,
  0x70,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x52,0x65,0x6d,0x6f,
  0x74,0x65,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,
  0x71,0x6d,0x6c,0xa,0x53,0x63,0x72,0x65,0x65,0x6e,0x73,0x68,0x6f,0x74,0x44,0x69,
  0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,0x63,0x72,0x65,0x65,0x6e,0x73,
  0x68,0x6f,0x74,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x44,0x79,
  0x6e,0x61,0x6d,0x69,0x63,0x4c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x44,0x69,0x61,
  0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x44,0x79,0x6e,0x61,0x6d,0x69,0x63,0x4c,
  0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x50,0x69,0x70,0x65,0x57,0x69,0x72,0x65,0x44,0x65,0x6c,0x65,0x67,0x61,
  0x74,0x65,0x20,0x31,0x2e,0x30,0x20,0x50,0x69,0x70,0x65,0x57,0x69,0x72,0x65,0x44,
  0x65,0x6c,0x65,0x67,0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x49,0x6e,0x70,0x75,
  0x74,0x43,0x61,0x70,0x74,0x75,0x72,0x65,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,
  0x2e,0x30,0x20,0x49,0x6e,0x70,0x75,0x74,0x43,0x61,0x70,0x74,0x75,0x72,0x65,0x44,
  0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x6c,0x6f,0x62,0x61,0x6c,
  0x53,0x68,0x6f,0x72,0x74,0x63,0x75,0x74,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,
  0x31,0x2e,0x30,0x20,0x47,0x6c,0x6f,0x62,0x61,0x6c,0x53,0x68,0x6f,0x72,0x74,0x63,
  0x75,0x74,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,0x6c,0xa,0x57,0x61,
  0x6c,0x6c,0x70,0x61,0x70,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,
  0x30,0x20,0x57,0x61,0x6c,0x6c,0x70,0x61,0x70,0x65,0x72,0x44,0x69,0x61,0x6c,0x6f,
  0x67,0x2e,0x71,0x6d,0x6c,0xa,0x52,0x65,0x67,0x69,0x6f,0x6e,0x53,0x65,0x6c,0x65,
  0x63,0x74,0x4f,0x76,0x65,0x72,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x52,0x65,
  0x67,0x69,0x6f,0x6e,0x53,0x65,0x6c,0x65,0x63,0x74,0x4f,0x76,0x65,0x72,0x6c,0x61,
  0x79,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x6c,0x6f,0x61,0x74,0x69,0x6e,0x67,0x54,0x65,
  0x78,0x74,0x42,0x6f,0x78,0x20,0x31,0x2e,0x30,0x20,0x46,0x6c,0x6f,0x61,0x74,0x69,
  0x6e,0x67,0x54,0x65,0x78,0x74,0x42,0x6f,0x78,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x6c,
  0x6f,0x61,0x74,0x69,0x6e,0x67,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,
  0x20,0x31,0x2e,0x30,0x20,0x46,0x6c,0x6f,0x61,0x74,0x69,0x6e,0x67,0x42,0x61,0x63,
  0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // xdgdesktopportal
  0x0,0x10,
  0x2,0xe5,0x67,0xdc,
  0x0,0x78,
  0x0,0x64,0x0,0x67,0x0,0x64,0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x61,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/xdgdesktopportal
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/xdgdesktopportal/qmldir
  0x0,0x0,0x0,0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xb,0xbf,0xc0,0xae,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_xdgdesktopportal)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_xdgdesktopportal)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
